@@ -1,9 +1,10 @@
 #!/usr/bin/env python
-__version__ = '1.0.14'
+__version__ = '1.2.4'
 
 from    pathlib                 import Path
 
 import  os, sys, json
+os.environ['XDG_CONFIG_HOME'] = '/tmp'
 import  pudb
 from    pudb.remote             import set_trace
 
@@ -399,7 +400,11 @@ def pfprint(pftelspec:str, message:str, **kwargs) -> str:
                 print('%s' % e)
                 print("ERROR - could not POST to remote server!")
         except:
+            print(f"ERROR: {protocol}://{hostport} ")
             print("ERROR - could not connect to remote server!")
-    except:
+    except Exception as e:
+        print(f'ERROR input        >>{pftelspec}<<')
+        print(f"ERROR in processed >>{pftelsub}<<")
+        print(f"ERROR: {e}")
         print("ERROR -- the pftel DB URL spec seems invalid!")
     return d_log
